==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/TranslateRotate/ts/TranslateRotate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>TranslateRotate</name>
    <message>
        <location filename="../TranslateRotate.ui" line="+17"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location filename="../TranslateRotateInit.js" line="+2"/>
        <source>M&amp;ove and Rotate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przesuń i &amp;obróć</translatorcomment>
        <translation type="unfinished">Przesuń i &amp;obróć</translation>
    </message>
</context>
<context>
    <name>TranslateRotateOptions</name>
    <message>
        <location filename="../TranslateRotateDialog.ui" line="+14"/>
        <source>Move and Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przesuwania/obracania</translatorcomment>
        <translation type="unfinished">Opcje przesuwania/obracania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation type="unfinished">Kopie &amp;wielokrotne</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt (a):</translatorcomment>
        <translation type="unfinished">&amp;Kąt (a):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/TranslateRotate/ts/TranslateRotate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>TranslateRotate</name>
    <message>
        <location filename="../TranslateRotate.ui" line="+17"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location filename="../TranslateRotateInit.js" line="+2"/>
        <source>M&amp;ove and Rotate</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Przesuń i &amp;obróć</translatorcomment>
        <translation>P&amp;rzenieś i obróć</translation>
    </message>
</context>
<context>
    <name>TranslateRotateOptions</name>
    <message>
        <location filename="../TranslateRotateDialog.ui" line="+14"/>
        <source>Move and Rotate Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przesuwania/obracania</translatorcomment>
        <translation>Opcje przenoszenia i obracania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation>&amp;Wielokrotne skopiowanie</translation>
    </message>
    <message>
        <location line="+94"/>
        <source>&amp;Angle (a):</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Kąt (a):</translatorcomment>
        <translation>&amp;Kąt (a):</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
</TS>
